%plotXRD.m: Plots the X-ray diffraction patterns of Ge-Sn perovskite thin
%films
% Written 12/6/17 by Robert Hoye

clear;
clc;

sizeLine = 1;

% Load powder diffraction patterns
Sn_PDF = importdata('tin perovskite powder diffraction pattern.csv');
Ge_PDF = importdata('Ge perovskite powder diffraction pattern.csv');

% Load thin film XRD 
fileID = fopen('0Ge_film.asc');
Ge0_thinfilm = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge0_thinfilm = cell2mat(Ge0_thinfilm);
fclose(fileID);

fileID = fopen('25Ge_film.asc');
Ge25_thinfilm = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge25_thinfilm = cell2mat(Ge25_thinfilm);
fclose(fileID);

fileID = fopen('50Ge_film.asc');
Ge50_thinfilm = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge50_thinfilm = cell2mat(Ge50_thinfilm);
fclose(fileID);

fileID = fopen('75Ge_film.asc');
Ge75_thinfilm = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge75_thinfilm = cell2mat(Ge75_thinfilm);
fclose(fileID);

fileID = fopen('100Ge_film.asc');
Ge100_thinfilm = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge100_thinfilm = cell2mat(Ge100_thinfilm);
fclose(fileID);

% Load powder XRD
fileID = fopen('0Ge_powder.asc');
data = textscan(fileID, '%f %f', 'CollectOutput', true);
data = cell2mat(data);
fclose(fileID);

Ge0_powder = zeros(length(data(:,1))/2-1,2);

for i = 1:(length(data(:,1))/2-1)
    
    Ge0_powder(i,1) = data(2*i-1,1);
    Ge0_powder(i,2) = data(2*i-1,2);
    
end;

fileID = fopen('25Ge_powder.asc');
Ge25_powder = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge25_powder = cell2mat(Ge25_powder);
fclose(fileID);

fileID = fopen('50Ge_powder.asc');
Ge50_powder = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge50_powder = cell2mat(Ge50_powder);
fclose(fileID);

fileID = fopen('75Ge_powder.asc');
Ge75_powder = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge75_powder = cell2mat(Ge75_powder);
fclose(fileID);

fileID = fopen('100Ge_powder.asc');
Ge100_powder = textscan(fileID, '%f %f', 'CollectOutput', true);
Ge100_powder = cell2mat(Ge100_powder);
fclose(fileID);

% Plot diffraction patterns

f1 = figure;
f2 = figure;

% Powder diffraction patterns
figure(f1);
plot(Ge_PDF(:,1), Ge_PDF(:,2)./max(Ge_PDF(:,2)));
hold on;

figure(f1);
plot(Ge100_powder(:,1), Ge100_powder(:,2)./max(Ge100_powder(:,2)) + 1);
hold on;

figure(f1);
plot(Ge75_powder(:,1), Ge75_powder(:,2)./max(Ge75_powder(:,2)) + 2);
hold on;

figure(f1);
plot(Ge50_powder(:,1), Ge50_powder(:,2)./max(Ge50_powder(:,2)) + 3);
hold on;

figure(f1);
plot(Ge25_powder(:,1), Ge25_powder(:,2)./max(Ge25_powder(:,2)) + 4);
hold on;

figure(f1);
plot(Ge0_powder(:,1), Ge0_powder(:,2)./max(Ge0_powder(:,2)) + 5);
hold on;

figure(f1);
plot(Sn_PDF(:,1), Sn_PDF(:,2)./max(Sn_PDF(:,2)) + 6);

xlabel('2\theta (deg)'), ylabel('Normalized intensity (a.u.)');
axis([10 60 0 7]);

% Thin film diffraction patterns
figure(f2);
plot(Ge_PDF(:,1), Ge_PDF(:,2)./max(Ge_PDF(:,2)));
hold on;

figure(f2);
plot(Ge100_thinfilm(:,1), Ge100_thinfilm(:,2)./max(Ge100_thinfilm(:,2)) + 1);
hold on;

figure(f2);
plot(Ge75_thinfilm(:,1), Ge75_thinfilm(:,2)./max(Ge75_thinfilm(:,2)) + 2);
hold on;

figure(f2);
plot(Ge50_thinfilm(:,1), Ge50_thinfilm(:,2)./max(Ge50_thinfilm(:,2)) + 3);
hold on;

figure(f2);
plot(Ge25_thinfilm(:,1), Ge25_thinfilm(:,2)./max(Ge25_thinfilm(:,2)) + 4);
hold on;

figure(f2);
plot(Ge0_thinfilm(:,1), Ge0_thinfilm(:,2)./max(Ge0_thinfilm(:,2)) + 5);
hold on;

figure(f2);
plot(Sn_PDF(:,1), Sn_PDF(:,2)./max(Sn_PDF(:,2)) + 6);
xlabel('2\theta (deg)'), ylabel('Normalized intensity (a.u.)');
axis([10 60 0 7]);

